@@ -432,7 +432,8 @@ coelutionScore <- function(peak1, peak2, rawData){
   if (nrow(rawData) > 0){
     chrom1 <- rawData[rawData$peakID == peak1, c("int", "Scan")]
     chrom1 <- chrom1[order(chrom1$Scan),]
-    pred1 <- tryCatch({predict(smooth.spline(chrom1$Scan, chrom1$int), x = chrom1$Scan)},
+    pred1 <- tryCatch({stats::predict(stats::smooth.spline(chrom1$Scan, chrom1$int, spar = 0.4),
+                               x = chrom1$Scan)},
                       error = function(e) {return(list(x = chrom1$Scan, y = chrom1$int))})
     if(length(pred1) > 0){
       chrom1 <- data.frame(int = pred1$y, Scan = floor(chrom1$Scan))
@@ -440,7 +441,7 @@ coelutionScore <- function(peak1, peak2, rawData){
     scores <- sapply(peak2, function(x) {
       chrom2 <- rawData[rawData$peakID == x, c("int", "Scan")]
       chrom2 <- chrom2[order(chrom2$Scan),]
-      pred2 <- tryCatch({predict(smooth.spline(chrom2$Scan, chrom2$int),
+      pred2 <- tryCatch({stats::predict(stats::smooth.spline(chrom2$Scan, chrom2$int, spar = 0.4),
                                  x = chrom2$Scan)},
                         error = function(e) {return(list(x = chrom2$Scan,
                                                          y = chrom2$int))})
@@ -660,3 +661,36 @@ checkIntRules <- function(intrules, rates, intrequired, nchains, combinations,
   }
   return(passed)
 }
+
+# findMS2precursor
+#' find lisnks between MS1 peaks and precursors selected for MS2 in DDA
+#'
+#' Find lisnks between MS1 peaks and precursors selected for MS2 in DDA.
+#'
+#' @param mz mz
+#' @param minint minimum intensity
+#' @param maxint maximum intensity
+#' @param precursors data frame with all precursors
+#' @param ppm mass tolerance
+#'
+#' @returns peak-pick based on previous EIC clusters generated by \link{clustering}
+#'
+#' @keywords internal
+#'
+#' @author M Isabel Alcoriza-Balaguer <maialba@alumni.uv.es>
+findMS2precursor <- function(mz, minrt, maxrt, precursors, ppm){
+  fprec <- precursors[which(precursors$retentionTime >= minrt &
+                              precursors$retentionTime <= maxrt),]
+  if (nrow(fprec) > 0){
+    matches <- mzMatch(mz, fprec$precursor, ppm)
+    if (length(matches) > 0){
+      scans <- fprec$Scan[matches[seq(1, length(matches), 2)]]
+    } else {
+      scans <- c()
+    }
+  } else {
+    scans <- c()
+  }
+  return(scans)
+}
+
