@@ -20,17 +20,17 @@ readMSfile <- function(file){
                           endTime = ms[[1]]$metaData$endTime,
                           collisionEnergies = unique(unlist(lapply(ms, function(x) if(!is.null(x$metaData$collisionEnergy)){x$metaData$collisionEnergy} else {0}))))
   scansMetadata <-
-    data.frame(msLevel = unlist(lapply(ms, function(x) x$metaData$msLevel)),
-               polarity = unlist(lapply(ms, function(x) x$metaData$polarity)),
-               scanType = unlist(lapply(ms, function(x) x$metaData$scanType)),
-               centroided = unlist(lapply(ms, function(x) x$metaData$centroided)),
-               retentionTime = unlist(lapply(ms, function(x) x$metaData$retentionTime)),
-               peaksCount = unlist(lapply(ms, function(x) x$metaData$peaksCount)),
-               lowMz = unlist(lapply(ms, function(x) x$metaData$lowMz)),
-               highMz = unlist(lapply(ms, function(x) x$metaData$highMz)),
-               basePeakMz = unlist(lapply(ms, function(x) x$metaData$basePeakMz)),
-               basePeakInt = unlist(lapply(ms, function(x) x$metaData$basePeakInt)),
-               totIonCurrent = unlist(lapply(ms, function(x) x$metaData$totIonCurrent)),
+    data.frame(msLevel = unlist(lapply(ms, function(x) if(!is.null(x$metaData$msLevel)){x$metaData$msLevel} else {NA})),
+               polarity = unlist(lapply(ms, function(x) if(!is.null(x$metaData$polarity)){x$metaData$polarity} else {NA})),
+               scanType = unlist(lapply(ms, function(x) if(!is.null(x$metaData$scanType)){x$metaData$scanType} else {NA})),
+               centroided = unlist(lapply(ms, function(x) if(!is.null(x$metaData$centroided)){x$metaData$centroided} else {NA})),
+               retentionTime = unlist(lapply(ms, function(x) if(!is.null(x$metaData$retentionTime)){x$metaData$retentionTime} else {NA})),
+               peaksCount = unlist(lapply(ms, function(x) if(!is.null(x$metaData$peaksCount)){x$metaData$peaksCount} else {NA})),
+               lowMz = unlist(lapply(ms, function(x) if(!is.null(x$metaData$lowMz)){x$metaData$lowMz} else {NA})),
+               highMz = unlist(lapply(ms, function(x) if(!is.null(x$metaData$highMz)){x$metaData$highMz} else {NA})),
+               basePeakMz = unlist(lapply(ms, function(x) if(!is.null(x$metaData$basePeakMz)){x$metaData$basePeakMz} else {NA})),
+               basePeakInt = unlist(lapply(ms, function(x) if(!is.null(x$metaData$basePeakInt)){x$metaData$basePeakInt} else {NA})),
+               totIonCurrent = unlist(lapply(ms, function(x) if(!is.null(x$metaData$totIonCurrent)){x$metaData$totIonCurrent} else {NA})),
                precursor = unlist(lapply(ms, function(x) if(!is.null(x$metaData$precursorMz)){x$metaData$precursorMz} else {NA})),
                collisionEnergy = unlist(lapply(ms, function(x) if(!is.null(x$metaData$collisionEnergy)){x$metaData$collisionEnergy} else {0})),
                stringsAsFactors = FALSE)
